@@ -1,4 +1,3 @@
-use crate::commands::kv;
 use crate::http;
 use crate::kv::namespace::list;
 use crate::settings::global_user::GlobalUser;
@@ -7,8 +6,6 @@ use crate::settings::toml::Target;
 use anyhow::Result;
 
 pub fn run(target: &Target, user: &GlobalUser) -> Result<()> {
-    kv::validate_target(target)?;
-
     let client = http::cf_v4_client(user)?;
     let result = list(&client, target);
     match result {
